@@ -1,8 +1,8 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -34,9 +34,11 @@ import gc
 
 from optparse import OptionParser
 
-from common import Debug, StrMixin, isPython3, nativeString
+from common import Debug, StrMixin
 from util import removeIfExists, gitHead, checkMemory
-from compat import Csv, CsvWriter
+from util import Csv, CsvWriter, popenReadlines
+
+from kde import cacheDir
 
 # fields in row:
 RULESETFIELD = 0
@@ -51,16 +53,14 @@ OPTIONS = None
 
 KNOWNCOMMITS = set()
 
-class Clone(object):
+class Clone:
 
     """make a temp directory for commitId"""
 
-    cacheDirectory = os.path.expanduser(os.path.join('~', '.kajongg', '.cache'))
-
     def __init__(self, commitId):
         self.commitId = commitId
         if commitId != 'current':
-            tmpdir = os.path.expanduser(os.path.join(self.cacheDirectory, commitId))
+            tmpdir = os.path.expanduser(os.path.join(cacheDir(), commitId))
             if not os.path.exists(tmpdir):
                 subprocess.Popen('git clone --shared --no-checkout -q .. {temp}'.format(
                     temp=tmpdir).split()).wait()
@@ -73,19 +73,19 @@ class Clone(object):
             tmpdir = os.path.abspath('..')
             result = os.path.join(tmpdir, 'src')
         else:
-            result = os.path.join(self.cacheDirectory, self.commitId, 'src')
+            result = os.path.join(cacheDir(), self.commitId, 'src')
         assert os.path.exists(result), '{} does not exist'.format(result)
         return result
 
     @classmethod
     def removeObsolete(cls):
         """remove all clones for obsolete commits"""
-        for commitDir in os.listdir(cls.cacheDirectory):
+        for commitDir in os.listdir(cacheDir()):
             if not any(x.startswith(commitDir) for x in KNOWNCOMMITS):
-                removeDir = os.path.join(cls.cacheDirectory, commitDir)
+                removeDir = os.path.join(cacheDir(), commitDir)
                 shutil.rmtree(removeDir)
 
-class Client(object):
+class Client:
 
     """a simple container, assigning process to job"""
 
@@ -178,8 +178,6 @@ class Server(StrMixin):
             cmd.append('--socket={sock}'.format(sock=self.socketName))
         if OPTIONS.debug:
             cmd.append('--debug={dbg}'.format(dbg=','.join(OPTIONS.debug)))
-        if OPTIONS.qt5:
-            cmd.append('--qt5')
         if OPTIONS.log:
             self.process = subprocess.Popen(
                 cmd, cwd=job.srcDir(),
@@ -202,7 +200,7 @@ class Server(StrMixin):
             if self.process:
                 try:
                     self.process.terminate()
-                    _ = self.process.wait()
+                    self.process.wait()
                 except OSError:
                     pass
                 print('{} killed'.format(self))
@@ -219,11 +217,11 @@ class Server(StrMixin):
                 server.jobs)
             server.stop()
 
-    def __unicode__(self):
-        return u'Server {} Python{}{} {}'.format(
+    def __str__(self):
+        return 'Server {} Python{}{} {}'.format(
             self.commitId,
             self.pythonVersion,
-            ' pid={}'.format(self.process.pid) if Debug.process else u'',
+            ' pid={}'.format(self.process.pid) if Debug.process else '',
             'port={}'.format(self.portNumber) if self.portNumber else 'socket={}'.format(self.socketName))
 
 
@@ -270,7 +268,7 @@ class Job(StrMixin):
                '--game={game}'.format(game=self.game),
                '--player={tester} {player}'.format(
                    player=player,
-                   tester=nativeString(u'Tüster')),
+                   tester='Tüster'),
                '--ruleset={ap}'.format(ap=self.ruleset)]
         if self.server.socketName:
             cmd.append('--socket={sock}'.format(sock=self.server.socketName))
@@ -287,8 +285,6 @@ class Job(StrMixin):
             cmd.append('--demo')
         else:
             cmd.append('--nogui')
-        if OPTIONS.qt5:
-            cmd.append('--qt5')
         if OPTIONS.playopen:
             cmd.append('--playopen')
         if OPTIONS.debug:
@@ -328,14 +324,14 @@ class Job(StrMixin):
             if sum(x.startswith(self.ruleset[:prefix]) for x in names) == 1:
                 return self.ruleset[prefix - 1:]
 
-    def __unicode__(self):
-        pid = u'pid={}'.format(
-            self.process.pid) if self.process and Debug.process else u''
-        game = u'game={}'.format(self.game)
+    def __str__(self):
+        pid = 'pid={}'.format(
+            self.process.pid) if self.process and Debug.process else ''
+        game = 'game={}'.format(self.game)
         ruleset = self.shortRulesetName()
-        aiName = u'AI={}'.format(
-            self.aiVariant) if self.aiVariant != u'Default' else u''
-        return u' '.join([
+        aiName = 'AI={}'.format(
+            self.aiVariant) if self.aiVariant != 'Default' else ''
+        return ' '.join([
             self.commitId, 'Python{}'.format(self.pythonVersion), pid, game, ruleset, aiName]).replace('  ', ' ')
 
 
@@ -344,7 +340,7 @@ def neutralize(rows):
     for row in rows:
         for idx, field in enumerate(row):
             field = field.replace(' ', '')
-            if field.startswith(u'Tester ') or field.startswith(u'Tüster'):
+            if field.startswith('Tester ') or field.startswith('Tüster'):
                 field = 'Tester'
             if 'MEM' in field:
                 parts = field.split(',')
@@ -581,13 +577,6 @@ def parse_options():
     parser.add_option(
         '', '--gui', dest='gui', action='store_true',
         default=False, help='show graphical user interface')
-    parser.add_option(
-        '', '--23', dest='py23', action='store_true',
-        default=False, help='Use both Python 2 and 3. If you explicitly want to use only one of them'
-                            'use python2 kajonggtest or python3 kajonggtest')
-    parser.add_option(
-        '', '--qt5', dest='qt5', action='store_true',
-        default=False, help='Force using Qt5')
     parser.add_option(
         '', '--ruleset', dest='rulesets', default='ALL',
         help='play like a robot using RULESET: comma separated list. If missing, test all rulesets',
@@ -641,12 +630,8 @@ def improve_options():
         OPTIONS.servers = 1
 
     cmdPath = os.path.join(startingDir(), 'kajongg.py')
-    cmd = ['python', cmdPath, '--rulesets=']
-    OPTIONS.knownRulesets = subprocess.Popen(
-        cmd,
-        stdout=subprocess.PIPE).communicate()[0].decode().split('\n')
-    OPTIONS.knownRulesets = list(x.strip()
-                                 for x in OPTIONS.knownRulesets if x.strip())
+    cmd = ['python3', cmdPath, '--rulesets']
+    OPTIONS.knownRulesets = list(popenReadlines(cmd))
     if OPTIONS.rulesets == 'ALL':
         OPTIONS.rulesets = OPTIONS.knownRulesets
     else:
@@ -732,18 +717,14 @@ def allJobs():
                     OPTIONS.jobCount += 1
                     if OPTIONS.jobCount > OPTIONS.count:
                         raise StopIteration
-                    if OPTIONS.py23:
-                        yield Job(2, ruleset, aiVariant, commitId, game)
-                        yield Job(3, ruleset, aiVariant, commitId, game)
-                    else:
-                        yield Job(3 if isPython3 else 2, ruleset, aiVariant, commitId, game)
+                    yield Job(3, ruleset, aiVariant, commitId, game)
 
 def main():
     """parse options, play, evaluate results"""
     global OPTIONS  # pylint: disable=global-statement
 
     # we want only english in the logs because i18n and friends
-    # behave differently in kde and kdestub
+    # behave differently in kde and kde
     os.environ['LANG'] = 'en_US.UTF-8'
     (OPTIONS, args) = parse_options()
     OPTIONS.csv = os.path.expanduser(
